object Plugins {
    const val androidApplication = "com.android.application"
    const val androidLibrary = "com.android.library"
    const val kotlinAndroid = "kotlin-android"
    const val kotlinKapt = "kotlin-kapt"
    const val daggerHilt = "dagger.hilt.android.plugin"
    const val gsm = "com.google.gms.google-services"
    const val crashlytics = "com.google.firebase.crashlytics"
    const val ktlint = "org.jlleitschuh.gradle.ktlint"
}

object Repositories {
    const val mavenGradle = "https://plugins.gradle.org/m2/"
    const val mavenJitpack = "https://jitpack.io"
}

object Android {
    object DefaultConfig {
        const val applicationId = "com.x.jenci"
        const val compileSdk = 31
        const val minSdk = 23
        const val targetSdk = 31
        const val versionCode = 5
        const val versionName = "0.0.5.beta"

        object Property {
            const val versionPropertyName = "archivesBaseName"
            const val versionPropertyValue = "$applicationId-v$versionCode($versionName)"
        }
    }

    object Test {
        val instrumentationRunner by lazy { "androidx.test.runner.AndroidJUnitRunner" }
    }

    object Proguard {
        val consumerRules by lazy { "consumer-rules.pro" }
        val rules by lazy { "proguard-rules.pro" }
        val optimize by lazy { "proguard-android-optimize.txt" }
    }

    object Options {
        const val jvmTarget = "1.8"
    }

    object Excludes {
        const val AL_LGPL = "META-INF/{AL2.0,LGPL2.1}"
    }
}

object BuildTypes {
    const val DEBUG = "debug"
    const val RELEASE = "release"
}

object Properties {
    const val useSupportLibrary = true
    const val compose = true
    const val correctErrorTypes = true

    object Debug {
        const val isMinifyEnabled = false
    }

    object Release {
        const val isShrinkResources = true
        const val isMinifyEnabled = true
    }
}

object Project {
    val common by lazy { ":common" }
    val domain by lazy { ":domain" }
    val data by lazy { ":data" }
}

object Versions {

    object Classpath {
        const val gradle = "7.3+"
        const val kotlin = "1.6.10"
        const val dagger = "2.38.1"
        const val ktlint = "10.2.1"
        const val gsm = "4.3.10"
        const val crashlyticsGradle = "2.8.1"
    }

    const val core = "1.7.0"
    const val appCompat = "1.4.1"
    const val annotation = "1.3.0"
    const val compose = "1.1.1"
    const val liveData = "2.4.1"
    const val liveDataExt = "2.2.0"
    const val lifecycle = "2.4.1"
    const val composeMaterialIcon = "1.0.5"
    const val material = "1.5.0"
    const val datastore = "1.0.0"
    const val composeMaterial3 = "1.0.0-alpha05"
    const val composeNavigation = "2.4.0-rc01"
    const val coroutines = "1.5.2"
    const val room = "2.4.2"
    const val crypto = "1.1.0-alpha03"
    const val daggerHilt = "2.38.1"
    const val hiltNavigationCompose = "1.0.0"
    const val splashScreen = "1.0.0-beta01"

    const val moshi = "1.13.0"
    const val retrofit = "2.9.0"
    const val okHttp = "4.9.3"
    const val seismic = "1.0.3"
    const val chucker = "3.5.2"
    const val leakCanary = "2.8.1"

    const val accompanist = "0.24.2-alpha"
    const val firebase = "29.1.0"
    const val gson = "2.8.9"

    const val xException = "1.0.0"
    const val javax = "1"
    const val mpAndroidChart = "v3.1.0"
    const val timber = "5.0.1"

    const val jUnit = "4.+"
    const val jUnitExt = "1.1.3"
    const val espresso = "3.4.0"
}

object Deps {

    object Classpath {
        const val gradle = "com.android.tools.build:gradle:${Versions.Classpath.gradle}"
        const val kotlinGradle = "org.jetbrains.kotlin:kotlin-gradle-plugin:${Versions.Classpath.kotlin}"
        const val daggerHilt = "com.google.dagger:hilt-android-gradle-plugin:${Versions.Classpath.dagger}"
        const val ktlint = "org.jlleitschuh.gradle:ktlint-gradle:${Versions.Classpath.ktlint}"
        const val gsm = "com.google.gms:google-services:${Versions.Classpath.gsm}"
        const val crashlytics = "com.google.firebase:firebase-crashlytics-gradle:${Versions.Classpath.crashlyticsGradle}"
    }

    object AndroidX {
        val core by lazy { "androidx.core:core-ktx:${Versions.core}" }
        val splashScreen by lazy { "androidx.core:core-splashscreen:${Versions.splashScreen}" }
        val appCompat by lazy { "androidx.appcompat:appcompat:${Versions.appCompat}" }
        val annotation by lazy { "androidx.annotation:annotation:${Versions.annotation}" }
        val lifecycle by lazy { "androidx.lifecycle:lifecycle-runtime-ktx:${Versions.lifecycle}" }
        val liveDataKtx by lazy { "androidx.lifecycle:lifecycle-livedata-ktx:${Versions.liveData}" }
        val liveDataExt by lazy { "androidx.lifecycle:lifecycle-extensions:${Versions.liveDataExt}" }
        val compose by lazy { "androidx.compose.ui:ui:${Versions.compose}" }
        val composeFoundation by lazy { "androidx.compose.foundation:foundation:${Versions.compose}" }
        val composeUtil by lazy { "androidx.compose.ui:ui-util:${Versions.compose}" }
        val composePreview by lazy { "androidx.compose.ui:ui-tooling-preview:${Versions.compose}" }
        val composeActivity by lazy { "androidx.activity:activity-compose:${Versions.compose}" }
        val composeMaterialIcon by lazy { "androidx.compose.material:material-icons-extended:${Versions.composeMaterialIcon}" }
        val composeMaterial3 by lazy { "androidx.compose.material3:material3:${Versions.composeMaterial3}" }
        val composeNavigation by lazy { "androidx.navigation:navigation-compose:${Versions.composeNavigation}" }
        val hiltNavigationCompose by lazy { "androidx.hilt:hilt-navigation-compose:${Versions.hiltNavigationCompose}" }
        val cryptoKtx by lazy { "androidx.security:security-crypto-ktx:${Versions.crypto}" }
        val datastore by lazy { "androidx.datastore:datastore-preferences:${Versions.datastore}" }
        val roomKtx by lazy { "androidx.room:room-ktx:${Versions.room}" }
        val roomRuntimeApi by lazy { "androidx.room:room-runtime:${Versions.room}" }
        val roomCompilerProcessor by lazy { "androidx.room:room-compiler:${Versions.room}" }
    }

    object Google {
        val daggerHilt by lazy { "com.google.dagger:hilt-android:${Versions.daggerHilt}" }
        val daggerHiltCompilerKapt by lazy { "com.google.dagger:hilt-android-compiler:${Versions.daggerHilt}" }
        val material by lazy { "com.google.android.material:material:${Versions.material}" }
        val gson by lazy { "com.google.code.gson:gson:${Versions.gson}" }
    }

    object Square {
        val moshi by lazy { "com.squareup.moshi:moshi-kotlin:${Versions.moshi}" }
        val moshiConverter by lazy { "com.squareup.retrofit2:converter-moshi:${Versions.retrofit}" }
        val retrofit by lazy { "com.squareup.retrofit2:retrofit:${Versions.retrofit}" }
        val okHttpInterceptor by lazy { "com.squareup.okhttp3:logging-interceptor:${Versions.okHttp}" }
        val retrofitConverter by lazy { "com.squareup.retrofit2:converter-scalars:${Versions.retrofit}" }
        val seismic by lazy { "com.squareup:seismic:${Versions.seismic}" }
        val chuckerLibraryDebug by lazy { "com.github.chuckerteam.chucker:library:${Versions.chucker}" }
        val chuckerLibraryRelease by lazy { "com.github.chuckerteam.chucker:library-no-op:${Versions.chucker}" }
        val leakCanaryDebug by lazy { "com.squareup.leakcanary:leakcanary-android:${Versions.leakCanary}" }
    }

    object Accompanist {
        val accompanistPager by lazy { "com.google.accompanist:accompanist-pager:${Versions.accompanist}" }
        val accompanistPagerIndicator by lazy { "com.google.accompanist:accompanist-pager-indicators:${Versions.accompanist}" }
        val accompanistSystemUiController by lazy { "com.google.accompanist:accompanist-systemuicontroller:${Versions.accompanist}" }
        val accompanistFlowLayout by lazy { "com.google.accompanist:accompanist-flowlayout:${Versions.accompanist}" }
        val accompanistSwipeRefresh by lazy { "com.google.accompanist:accompanist-swiperefresh:${Versions.accompanist}" }
        val accompanistInsetsUi by lazy { "com.google.accompanist:accompanist-insets-ui:${Versions.accompanist}" }
        val accompanistNavigationAnimation by lazy { "com.google.accompanist:accompanist-navigation-animation:${Versions.accompanist}" }
    }

    object Firebase {
        val bomPlatform by lazy { "com.google.firebase:firebase-bom:${Versions.firebase}" }
        val crashlyticsKtx by lazy { "com.google.firebase:firebase-crashlytics-ktx" }
        val analyticsKtx by lazy { "com.google.firebase:firebase-analytics-ktx" }
    }

    object Other {
        val coroutines by lazy { "org.jetbrains.kotlinx:kotlinx-coroutines-android:${Versions.coroutines}" }
        val javax by lazy { "javax.inject:javax.inject:${Versions.javax}" }
        val mpAndroidChart by lazy { "com.github.PhilJay:MPAndroidChart:${Versions.mpAndroidChart}" }
        val xException by lazy { "com.github.ResulSilay:xException:${Versions.xException}" }
        val timber by lazy { "com.jakewharton.timber:timber:${Versions.timber}" }
    }

    object Test {
        val jUnit by lazy { "junit:junit:${Versions.jUnit}" }
        val jUnitExt by lazy { "androidx.test.ext:junit:${Versions.jUnitExt}" }
        val espresso by lazy { "androidx.test.espresso:espresso-core:${Versions.espresso}" }
        val composeUiJUnit by lazy { "androidx.compose.ui:ui-test-junit4:${Versions.compose}" }
        val composeUiJUnitTool by lazy { "androidx.compose.ui:ui-tooling:${Versions.compose}" }
    }
}